@@ -290,6 +290,8 @@ class SpatialMap:
 
     def __getitem__(self, idx):
         """Same rules as numpy indexing"""
+        if hasattr(idx, "contains"):
+            idx = idx.contains(*self.positions)  # got a Shape object -> evaluate it
         return self.__class__(self._data[idx], self._sites[idx])
 
     def cropped(self, **limits):
@@ -404,6 +406,8 @@ class StructureMap(SpatialMap):
 
     def __getitem__(self, idx):
         """Same rules as numpy indexing"""
+        if hasattr(idx, "contains"):
+            idx = idx.contains(*self.positions)  # got a Shape object -> evaluate it
         return self.__class__(self.data[idx], self._sites[idx], self._hoppings[idx],
                               [b[idx] for b in self._boundaries])
 
@@ -431,12 +435,7 @@ class StructureMap(SpatialMap):
             Additional plot arguments as specified in :func:`.structure_plot_properties`.
         """
         from .system import (plot_sites, plot_hoppings, plot_periodic_boundaries,
-                             structure_plot_properties)
-
-        ax = plt.gca()
-        ax.set_aspect('equal', 'datalim')
-        ax.set_xlabel('x (nm)')
-        ax.set_ylabel('y (nm)')
+                             structure_plot_properties, decorate_structure_plot)
 
         def to_radii(data):
             if not isinstance(site_radius, (tuple, list)):
@@ -462,8 +461,7 @@ class StructureMap(SpatialMap):
         plot_periodic_boundaries(self.positions, hop, self.boundaries, self.data,
                                  num_periods, **props)
 
-        pltutils.despine(trim=True)
-        pltutils.add_margin()
+        decorate_structure_plot(**props)
 
         if collection:
             plt.sci(collection)
@@ -534,9 +532,28 @@ class Structure:
 
     def __getitem__(self, idx):
         """Same rules as numpy indexing"""
+        if hasattr(idx, "contains"):
+            idx = idx.contains(*self.positions)  # got a Shape object -> evaluate it
+
         return Structure(self._sites[idx], self._hoppings[idx],
                          [b[idx] for b in self._boundaries])
 
+    def find_nearest(self, position, sublattice=""):
+        """Find the index of the atom closest to the given position
+
+        Parameters
+        ----------
+        position : array_like
+            Where to look.
+        sublattice : Optional[str]
+            Look for a specific sublattice site. By default any will do.
+
+        Returns
+        -------
+        int
+        """
+        return self._sites.find_nearest(position, sublattice)
+
     def cropped(self, **limits):
         """Return a copy which retains only the sites within the given limits
 
